Citing the package
^^^^^^^^^^^^^^^^^^

To cite or reference `py-pde` in other work, please refer to the `publication in
the Journal of Open Source Software <https://doi.org/10.21105/joss.02158>`_.
Here are the respective bibliographic records in Bibtex format:

.. code-block:: bibtex

    @article{py-pde,
        Author = {David Zwicker},
        Doi = {10.21105/joss.02158},
        Journal = {Journal of Open Source Software},
        Number = {48},
        Pages = {2158},
        Publisher = {The Open Journal},
        Title = {py-pde: A Python package for solving partial differential equations},
        Url = {https://doi.org/10.21105/joss.02158},
        Volume = {5},
        Year = {2020}
    }

and in RIS format:

.. code-block:: text

    TY  - JOUR
    AU  - Zwicker, David
    JO  - Journal of Open Source Software
    IS  - 48
    SP  - 2158
    PB  - The Open Journal
    T1  - py-pde: A Python package for solving partial differential equations
    UR  - https://doi.org/10.21105/joss.02158
    VL  - 5
    PY  - 2020
